@@ -7,6 +7,7 @@ import com.unciv.logic.civilization.diplomacy.RelationshipLevel
 import com.unciv.logic.map.tile.RoadStatus
 import com.unciv.models.ruleset.Policy
 import com.unciv.models.ruleset.tile.ResourceType
+import com.unciv.models.ruleset.tile.TileImprovement
 import com.unciv.models.ruleset.unique.StateForConditionals
 import com.unciv.models.ruleset.unique.UniqueTarget
 import com.unciv.models.ruleset.unique.UniqueType
@@ -92,41 +93,34 @@ class CivInfoStatsForNextTurn(val civInfo: Civilization) {
                 .map { it.params[0] }.toHashSet() // needs to be .toHashSet()ed,
         // Because we go over every tile in every city and check if it's in this list, which can get real heavy.
 
+        fun addMaintenanceUniques(road: TileImprovement, type: UniqueType, state: StateForConditionals) {
+            for (unique in road.getMatchingUniques(type, state))
+                transportationUpkeep.add(Stat.valueOf(unique.params[1]), unique.params[0].toFloat())
+        }
+
         for (city in civInfo.cities) {
             for (tile in city.getTiles()) {
                 if (tile.isCityCenter()) continue
                 if (tile.getUnpillagedRoad() == RoadStatus.None) continue // Cheap checks before pricey checks
                 if (ignoredTileTypes.any { tile.matchesFilter(it, civInfo) }) continue
-                val road = tile.getUnpillagedRoadImprovement()
-                if (road!!.hasUnique(UniqueType.ImprovementMaintenance, StateForConditionals(civInfo, tile = tile))) {
-                    for(unique in road.getMatchingUniques(UniqueType.ImprovementMaintenance)) {
-                        transportationUpkeep.add(Stat.valueOf(unique.params[1]), unique.params[0].toFloat())
-                    }
-                }
-                if (road.hasUnique(UniqueType.ImprovementAllMaintenance, StateForConditionals(civInfo, tile = tile))) {
-                    for(unique in road.getMatchingUniques(UniqueType.ImprovementAllMaintenance)) {
-                        transportationUpkeep.add(Stat.valueOf(unique.params[1]), unique.params[0].toFloat())
-                    }
-                }
-                // backwards compatible
-                if (road.hasUnique(UniqueType.OldImprovementMaintenance, StateForConditionals(civInfo, tile = tile))) {
-                    transportationUpkeep.add(Stat.Gold, tile.getUnpillagedRoad().upkeep.toFloat())
-                }
+                val road = tile.getUnpillagedRoadImprovement()!!  // covered by RoadStatus.None test
+                val stateForConditionals = StateForConditionals(civInfo, tile = tile)
+                addMaintenanceUniques(road, UniqueType.ImprovementMaintenance, stateForConditionals)
+                addMaintenanceUniques(road, UniqueType.ImprovementAllMaintenance, stateForConditionals)
             }
         }
+
         // tabulate neutral roads
         for (position in civInfo.neutralRoads) {
             val tile = civInfo.gameInfo.tileMap[position]
             if (tile.getUnpillagedRoad() == RoadStatus.None) continue // Cheap checks before pricey checks
-            val road = tile.getUnpillagedRoadImprovement()
-            if (road!!.hasUnique(UniqueType.ImprovementAllMaintenance, StateForConditionals(civInfo, tile = tile))) {
-                for(unique in road.getMatchingUniques(UniqueType.ImprovementAllMaintenance)) {
-                    transportationUpkeep.add(Stat.valueOf(unique.params[1]), unique.params[0].toFloat())
-                }
-            }
+            val road = tile.getUnpillagedRoadImprovement()!!  // covered by RoadStatus.None test
+            val stateForConditionals = StateForConditionals(civInfo, tile = tile)
+            addMaintenanceUniques(road, UniqueType.ImprovementAllMaintenance, stateForConditionals)
         }
+
         for (unique in civInfo.getMatchingUniques(UniqueType.RoadMaintenance))
-            transportationUpkeep.times(unique.params[0].toPercent())
+            transportationUpkeep.timesInPlace(unique.params[0].toPercent())
 
         return transportationUpkeep
     }
@@ -175,9 +169,8 @@ class CivInfoStatsForNextTurn(val civInfo: Civilization) {
         //City-States bonuses
         for (otherCiv in civInfo.getKnownCivs()) {
             if (!otherCiv.isCityState()) continue
-            if (otherCiv.getDiplomacyManager(civInfo.civName)
-                        .relationshipLevel() != RelationshipLevel.Ally
-            ) continue
+            if (!otherCiv.getDiplomacyManager(civInfo.civName).isRelationshipLevelEQ(RelationshipLevel.Ally))
+                continue
             for (unique in civInfo.getMatchingUniques(UniqueType.CityStateStatPercent)) {
                 statMap.add(
                     Constants.cityStates,
@@ -235,10 +228,10 @@ class CivInfoStatsForNextTurn(val civInfo: Civilization) {
         for (unique in civInfo.getMatchingUniques(UniqueType.BonusHappinessFromLuxury))
             happinessPerUniqueLuxury += unique.params[0].toInt()
 
-        val ownedLuxuries = civInfo.getCivResources().map { it.resource }
+        val ownedLuxuries = civInfo.getCivResourceSupply().map { it.resource }
             .filter { it.resourceType == ResourceType.Luxury }
 
-        val relevantLuxuries = civInfo.getCivResources().asSequence()
+        val relevantLuxuries = civInfo.getCivResourceSupply().asSequence()
             .map { it.resource }
             .count { it.resourceType == ResourceType.Luxury
                     && it.getMatchingUniques(UniqueType.ObsoleteWith)
@@ -250,7 +243,7 @@ class CivInfoStatsForNextTurn(val civInfo: Civilization) {
 
         val luxuriesProvidedByCityStates = civInfo.getKnownCivs().asSequence()
             .filter { it.isCityState() && it.getAllyCiv() == civInfo.civName }
-            .flatMap { it.getCivResources().map { res -> res.resource } }
+            .flatMap { it.getCivResourceSupply().map { res -> res.resource } }
             .distinct()
             .count { it.resourceType === ResourceType.Luxury && ownedLuxuries.contains(it) }
 
