@@ -14,7 +14,6 @@ import com.unciv.logic.civilization.PopupAlert
 import com.unciv.logic.civilization.diplomacy.DiplomacyFlags
 import com.unciv.logic.civilization.diplomacy.DiplomacyManager
 import com.unciv.logic.civilization.diplomacy.DiplomaticModifiers
-import com.unciv.logic.civilization.diplomacy.DiplomaticModifiers.*
 import com.unciv.logic.civilization.diplomacy.DiplomaticStatus
 import com.unciv.logic.civilization.diplomacy.RelationshipLevel
 import com.unciv.logic.civilization.managers.AssignedQuest
@@ -29,6 +28,7 @@ import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.translations.tr
 import com.unciv.ui.audio.MusicMood
 import com.unciv.ui.audio.MusicTrackChooserFlags
+import com.unciv.ui.components.ColorMarkupLabel
 import com.unciv.ui.components.Fonts
 import com.unciv.ui.components.KeyCharAndCode
 import com.unciv.ui.components.UncivTooltip.Companion.addTooltip
@@ -151,7 +151,7 @@ class DiplomacyScreen(
                 questIcon.x = floor(civIndicator.width - questIcon.width)
             }
 
-            val civNameLabel = civ.civName.toLabel()
+            val civNameLabel = civ.civName.toLabel(hideIcons = true)
             leftSideTable.add(civIndicator).row()
             leftSideTable.add(civNameLabel).padBottom(20f).row()
 
@@ -256,7 +256,7 @@ class DiplomacyScreen(
         val allyBonusObjects = viewingCiv.cityStateFunctions.getCityStateBonuses(otherCiv.cityStateType, RelationshipLevel.Ally)
         allyBonusText += allyBonusObjects.joinToString(separator = "\n") { it.text.tr() }
 
-        val relationLevel = otherCivDiplomacyManager.relationshipLevel()
+        val relationLevel = otherCivDiplomacyManager.relationshipIgnoreAfraid()
         if (relationLevel >= RelationshipLevel.Friend) {
             // RelationshipChange = Ally -> Friend or Friend -> Favorable
             val turnsToRelationshipChange = otherCivDiplomacyManager.getTurnsToRelationshipChange()
@@ -266,12 +266,12 @@ class DiplomacyScreen(
         }
 
         val friendBonusLabelColor = if (relationLevel == RelationshipLevel.Friend) Color.GREEN else Color.GRAY
-        val friendBonusLabel = friendBonusText.toLabel(friendBonusLabelColor)
+        val friendBonusLabel = ColorMarkupLabel(friendBonusText, friendBonusLabelColor)
             .apply { setAlignment(Align.center) }
         diplomacyTable.add(friendBonusLabel).row()
 
         val allyBonusLabelColor = if (relationLevel == RelationshipLevel.Ally) Color.GREEN else Color.GRAY
-        val allyBonusLabel = allyBonusText.toLabel(allyBonusLabelColor)
+        val allyBonusLabel = ColorMarkupLabel(allyBonusText, allyBonusLabelColor)
             .apply { setAlignment(Align.center) }
         diplomacyTable.add(allyBonusLabel).row()
 
@@ -350,7 +350,8 @@ class DiplomacyScreen(
                 updateRightSide(otherCiv)
             }.open()
         }
-        if (isNotPlayersTurn() || !otherCiv.cityStateFunctions.otherCivCanWithdrawProtection(viewingCiv)) revokeProtectionButton.disable()
+        if (isNotPlayersTurn() || !otherCiv.cityStateFunctions.otherCivCanWithdrawProtection(viewingCiv))
+            revokeProtectionButton.disable()
         return revokeProtectionButton
     }
 
@@ -368,7 +369,8 @@ class DiplomacyScreen(
                 updateRightSide(otherCiv)
             }.open()
         }
-        if (isNotPlayersTurn() || !otherCiv.cityStateFunctions.otherCivCanPledgeProtection(viewingCiv)) protectionButton.disable()
+        if (isNotPlayersTurn() || !otherCiv.cityStateFunctions.otherCivCanPledgeProtection(viewingCiv))
+            protectionButton.disable()
         return protectionButton
     }
 
@@ -461,7 +463,8 @@ class DiplomacyScreen(
             for (city in newCities)
                 viewingCiv.popupAlerts.add(PopupAlert(AlertType.DiplomaticMarriage, city.id))   // Player gets to choose between annex and puppet
         }
-        if (isNotPlayersTurn() || !otherCiv.cityStateFunctions.canBeMarriedBy(viewingCiv)) diplomaticMarriageButton.disable()
+        if (isNotPlayersTurn() || !otherCiv.cityStateFunctions.canBeMarriedBy(viewingCiv))
+            diplomaticMarriageButton.disable()
         return diplomaticMarriageButton
     }
 
@@ -637,7 +640,7 @@ class DiplomacyScreen(
         val diplomacyTable = Table()
         diplomacyTable.defaults().pad(10f)
 
-        val helloText = if (otherCivDiplomacyManager.relationshipLevel() <= RelationshipLevel.Enemy)
+        val helloText = if (otherCivDiplomacyManager.isRelationshipLevelLE(RelationshipLevel.Enemy))
             otherCiv.nation.hateHello
         else otherCiv.nation.neutralHello
         val leaderIntroTable = LeaderIntroTable(otherCiv, helloText)
@@ -824,8 +827,8 @@ class DiplomacyScreen(
         val diplomacyModifiersTable = Table()
         for (modifier in otherCivDiplomacyManager.diplomaticModifiers) {
             // Angry about attacked CS and destroyed CS do not stack
-            if (modifier.key == AttackedProtectedMinor.name
-                && otherCivDiplomacyManager.hasModifier(DestroyedProtectedMinor))
+            if (modifier.key == DiplomaticModifiers.AttackedProtectedMinor.name
+                && otherCivDiplomacyManager.hasModifier(DiplomaticModifiers.DestroyedProtectedMinor))
                 continue
 
             var text = DiplomaticModifiers.valueOf(modifier.key).text.tr() + " "
