@@ -22,8 +22,10 @@ import com.unciv.ui.components.extensions.isEnabled
 import com.unciv.ui.components.extensions.keyShortcuts
 import com.unciv.ui.components.extensions.onActivation
 import com.unciv.ui.components.extensions.toTextButton
+import com.unciv.utils.Concurrency
 import com.unciv.utils.Log
-import kotlin.concurrent.thread
+import kotlinx.coroutines.CoroutineScope
+import kotlinx.coroutines.isActive
 
 class MapEditorLoadTab(
     private val editorScreen: MapEditorScreen,
@@ -32,7 +34,9 @@ class MapEditorLoadTab(
     private val mapFiles = MapEditorFilesTable(
         initWidth = editorScreen.getToolsWidth() - 20f,
         includeMods = true,
-        this::selectFile)
+        this::selectFile,
+        this::loadHandler
+    )
 
     private val loadButton = "Load map".toTextButton()
     private val deleteButton = "Delete map".toTextButton()
@@ -53,7 +57,7 @@ class MapEditorLoadTab(
         val fileTableHeight = editorScreen.stage.height - headerHeight - buttonTable.height - 2f
         val scrollPane = AutoScrollPane(mapFiles, skin)
         scrollPane.setOverscroll(false, true)
-        add(scrollPane).height(fileTableHeight).width(editorScreen.getToolsWidth() - 20f).row()
+        add(scrollPane).size(editorScreen.getToolsWidth() - 20f, fileTableHeight).padTop(10f).row()
         add(buttonTable).row()
     }
 
@@ -63,7 +67,7 @@ class MapEditorLoadTab(
             "Do you want to load another map without saving the recent changes?",
             "Load map"
         ) {
-            thread(name = "MapLoader", isDaemon = true, block = this::loaderThread)
+            editorScreen.startBackgroundJob("MapLoader") { loaderThread() }
         }
     }
 
@@ -89,18 +93,18 @@ class MapEditorLoadTab(
         pager.setScrollDisabled(false)
     }
 
-    fun selectFile(file: FileHandle?) {
+    private fun selectFile(file: FileHandle?) {
         chosenMap = file
         loadButton.isEnabled = (file != null)
         deleteButton.isEnabled = (file != null)
         deleteButton.color = if (file != null) Color.SCARLET else Color.BROWN
     }
 
-    fun loaderThread() {
+    private fun CoroutineScope.loaderThread() {
         var popup: Popup? = null
         var needPopup = true    // loadMap can fail faster than postRunnable runs
-        Gdx.app.postRunnable {
-            if (!needPopup) return@postRunnable
+        Concurrency.runOnGLThread {
+            if (!needPopup) return@runOnGLThread
             popup = Popup(editorScreen).apply {
                 addGoodSizedLabel(Constants.loading)
                 open()
@@ -108,6 +112,7 @@ class MapEditorLoadTab(
         }
         try {
             val map = MapSaver.loadMap(chosenMap!!)
+            if (!isActive) return
 
             val missingMods = map.mapParameters.mods.filter { it !in RulesetCache }.toMutableList()
             // [TEMPORARY] conversion of old maps with a base ruleset contained in the mods
@@ -117,12 +122,12 @@ class MapEditorLoadTab(
             if (map.mapParameters.baseRuleset !in RulesetCache) missingMods += map.mapParameters.baseRuleset
 
             if (missingMods.isNotEmpty()) {
-                Gdx.app.postRunnable {
+                Concurrency.runOnGLThread {
                     needPopup = false
                     popup?.close()
                     ToastPopup("Missing mods: [${missingMods.joinToString()}]", editorScreen)
                 }
-            } else Gdx.app.postRunnable {
+            } else Concurrency.runOnGLThread {
                 Gdx.input.inputProcessor = null // This is to stop ANRs happening here, until the map editor screen sets up.
                 try {
                     // For deprecated maps, set the base ruleset field if it's still saved in the mods field
@@ -155,7 +160,7 @@ class MapEditorLoadTab(
             }
         } catch (ex: Throwable) {
             needPopup = false
-            Gdx.app.postRunnable {
+            Concurrency.runOnGLThread {
                 popup?.close()
                 Log.error("Error loading map \"$chosenMap\"", ex)
 
